CancelTaskSet

Struct CancelTaskSet 

pub struct CancelTaskSet {
    pub join_set: JoinSet<Result<(), Error>>,
    /* private fields */
}
A combination of a tokio::task::JoinSet and tokio_util::sync::CancellationToken.

Provides methods that are commonly used in conjunction with those two data structures.

Fields

join_set: JoinSet<Result<(), Error>>

Task set join set.

Implementations

Source

impl CancelTaskSet

pub fn new() -> Self

Creates a new task set.

pub fn new_with_signal_handler() -> Self

Creates a task set and registers a signal handler that calls cancel() on the cancellation token upon receiving SIGINT and SIGTERM.

pub fn from_cancel_token( register_signal_handler: bool, cancellation_token: CancellationToken, ) -> Self

Creates a task set from an existing cancellation token.

Arguments
  • register_signal_handler: If true, a signal handler is registered that calls cancel() on the cancellation token upon receiving SIGINT and SIGTERM.
  • cancellation_token: The cancellation token to use.
pub fn cancellation_token(&self) -> CancellationToken

Returns a clone of the cancellation token.

pub fn spawn_cancellable_task<Fut>(&mut self, task: Fut)
where Fut: Future<Output = Result<(), Error>> + Send + 'static,

Spawns a task that will run until it is cancelled or completes.

pub async fn join_all(&mut self)

Joins all tasks in the set. If any task fails to join or returns an error, cancel the token to signal a graceful shutdown to the remaining tasks.